/*
 * Copyright 2008 University of Chicago/Argonne National Laboratory
 *
 * @author Neill Miller
 */
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include "soapH.h"
#include "libglobus_adq.h"

#define VERSION "0.9.0"

int main(int argc, char **argv)
{
    int ret = -1;

    if (argc < 4)
    {
        if ((argv[1] != NULL) && ((strcmp(argv[1], "-v") == 0) || (strcmp(argv[1], "--version") == 0)))
        {
            printf("%s\n", VERSION);
            goto error_exit;
        }

        fprintf(stderr, "Usage: %s <AUTHZ_SERVICE_URL> <OPENID> <RESOURCE> [-v|--version]\n\n", argv[0]);
        fprintf(stderr, "An example command line may look like:\n\t%s https://localhost/esgcet/saml/soap/secure/authorizationService.htm https://myopenid.com/testUser gsiftp://localhost:2811//data/file.nc\n", argv[0]);
        goto error_exit;
    }

    authz_decision_t authz_out;
    memset(&authz_out, 0, sizeof(authz_out));

    char *authz_service = argv[1];
    char *openid = argv[2];
    char *resource = argv[3];

    ret = get_authorization_decision(
        (char *)authz_service, (char *)openid, (char *)resource,
        (char *)"read", &authz_out);

    if (ret == 0)
    {
        printf("Authz Decision returned successfully for Openid %s\n", openid);
        printf("Resource %s, Action %s, Decision %s\n", authz_out.resource, authz_out.action,
               ((authz_out.decision == ADQ_PERMIT) ? "Permit" : "Not Permitted"));
    }
    else
    {
        printf("Authz Decision Query failed for Openid %s\n", openid);
    }
    return 0;

  error_exit:
    exit(1);
} 
